# PyDiamond

Diamond is a simple automation language built on Python + Selenium.  
It allows you to open websites, click elements, type text, and more using easy commands.

## Installation

```bash
pip install diamond
